%global packname Rcpp

Name:		R-%{packname}
Version:	0.12.9
Release:	1%{?dist}
Summary:	Seamless R and C++ Integration

#		The following three files uses the Boost Software License:
#		- Rcpp/inst/include/Rcpp/utils/tinyformat.h
#		- Rcpp/inst/include/Rcpp/macros/config.hpp
#		- Rcpp/inst/include/Rcpp/macros/cat.hpp
License:	GPLv2+ and Boost
URL:		http://cran.r-project.org/web/packages/%{packname}/
Source0:	ftp://cran.r-project.org/pub/R/contrib/main/%{packname}_%{version}.tar.gz

BuildRequires:	R-core-devel
BuildRequires:	R-RUnit
BuildRequires:	R-highlight
BuildRequires:	R-inline
BuildRequires:	dos2unix
%if %{?fedora}%{!?fedora:0}
#		These are needed also for EPEL 7, but are missing.
#		https://bugzilla.redhat.com/show_bug.cgi?id=1309785
BuildRequires:	tex(vmargin.sty)
BuildRequires:	tex(mathdesign.sty)
BuildRequires:	tex(texnansi.enc)
%endif
Requires:	R-core%{?_isa}

%description
The Rcpp package provides R functions as well as C++ classes which
offer a seamless integration of R and C++. Many R data types and
objects can be mapped back and forth to C++ equivalents which
facilitates both writing of new code as well as easier integration of
third-party libraries.
Documentation about Rcpp is provided by several vignettes included in
this package, via the Rcpp Gallery site at http://gallery.rcpp.org,
the paper by Eddelbuettel and Francois (2011, JSS), and the book by
Eddelbuettel (2013, Springer).
See citation("Rcpp") for details on the last two.

%package devel
Summary:	Rcpp Development Files
Requires:	%{name}%{?_isa} = %{version}-%{release}
Requires:	R-core-devel%{?_isa}

%description devel
Header files for Rcpp.

%package examples
Summary:	Rcpp Examples
Requires:	%{name}%{?_isa} = %{version}-%{release}

%description examples
Examples for using Rcpp.

%prep
%setup -q -c

dos2unix -k %{packname}/inst/include/Rcpp/sugar/functions/cbind.h \
    %{packname}/inst/unitTests/cpp/InternalFunction.cpp \
    %{packname}/inst/unitTests/cpp/InternalFunctionCPP11.cpp

%build

%install
mkdir -p %{buildroot}%{_libdir}/R/library
%{_bindir}/R CMD INSTALL -l %{buildroot}%{_libdir}/R/library %{packname}
test -d %{packname}/src && (cd %{packname}/src; rm -f *.o *.so)
rm -rf %{buildroot}%{_libdir}/R/library/R.css
rm -rf %{buildroot}%{_libdir}/R/library/%{packname}/unitTests

sed 's!/bin/env Rscript!/usr/bin/Rscript!' \
    -i %{buildroot}%{_libdir}/R/library/%{packname}/discovery/cxx0x.R
chmod 755 %{buildroot}%{_libdir}/R/library/%{packname}/discovery/cxx0x.R

for f in ConvolveBenchmarks/overhead.r ConvolveBenchmarks/overhead.sh \
	 Misc/ifelseLooped.r Misc/newFib.r OpenMP/OpenMPandInline.r ; do
    chmod 755 %{buildroot}%{_libdir}/R/library/%{packname}/examples/$f
done

for f in `find %{buildroot}%{_libdir}/R/library/%{packname}/examples -type f` ; do
    grep -q '/usr/bin/env r' $f && sed 's!/usr/bin/env r!/usr/bin/r!' -i $f
done

%check
_R_CHECK_FORCE_SUGGESTS_=0 %{_bindir}/R CMD check %{packname}

%files
%dir %{_libdir}/R/library/%{packname}
%doc %{_libdir}/R/library/%{packname}/NEWS.Rd
%doc %{_libdir}/R/library/%{packname}/README
%doc %{_libdir}/R/library/%{packname}/THANKS
%doc %{_libdir}/R/library/%{packname}/announce
%doc %{_libdir}/R/library/%{packname}/bib
%doc %{_libdir}/R/library/%{packname}/doc
%doc %{_libdir}/R/library/%{packname}/html
%{_libdir}/R/library/%{packname}/CITATION
%{_libdir}/R/library/%{packname}/DESCRIPTION
%{_libdir}/R/library/%{packname}/INDEX
%{_libdir}/R/library/%{packname}/NAMESPACE
%{_libdir}/R/library/%{packname}/Meta
%{_libdir}/R/library/%{packname}/R
%{_libdir}/R/library/%{packname}/discovery
%{_libdir}/R/library/%{packname}/help
%{_libdir}/R/library/%{packname}/libs
%{_libdir}/R/library/%{packname}/prompt
%{_libdir}/R/library/%{packname}/skeleton

%files devel
%{_libdir}/R/library/%{packname}/include

%files examples
%{_libdir}/R/library/%{packname}/examples

%changelog
* Mon Jan 16 2017 Mattias Ellert <mattias.ellert@physics.uu.se> - 0.12.9-1
- Update to 0.12.9

* Fri Dec 02 2016 Mattias Ellert <mattias.ellert@physics.uu.se> - 0.12.8-1
- Update to 0.12.8

* Tue Sep 06 2016 Mattias Ellert <mattias.ellert@physics.uu.se> - 0.12.7-1
- Update to 0.12.7

* Fri Jul 22 2016 Mattias Ellert <mattias.ellert@physics.uu.se> - 0.12.6-1
- Update to 0.12.6

* Tue May 24 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 0.12.5-1
- Update to 0.12.5

* Sun Apr 10 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 0.12.4-1
- Update to 0.12.4

* Tue Feb 23 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 0.12.3-3
- Adjust BuildRequires for EPEL
- Replace /usr/bin/env shebang
- Set executable permission on script with shebang

* Thu Feb 18 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 0.12.3-2
- Fix license tag (add Boost)

* Fri Feb 05 2016 Mattias Ellert <mattias.ellert@fysast.uu.se> - 0.12.3-1
- Initial package creation
